InteractiveClapContextScopeForSignWith

Type Alias InteractiveClapContextScopeForSignWith 

pub type InteractiveClapContextScopeForSignWith = SignWithDiscriminants;

Aliased Type

pub enum InteractiveClapContextScopeForSignWith {
    SignWithKeychain,
    SignWithLegacyKeychain,
    SignWithLedger,
    SignWithPlaintextPrivateKey,
    SignWithAccessKeyFile,
    SignWithSeedPhrase,
    SignLater,
}

Variants



SignWithKeychain

Sign the transaction with a key saved in keychain



SignWithLegacyKeychain

Sign the transaction with a key saved in legacy keychain (compatible with the old unc CLI)



SignWithLedger

Sign the transaction with Ledger Nano device



SignWithPlaintextPrivateKey

Sign the transaction with a plaintext private key



SignWithAccessKeyFile

Sign the transaction using the account access key file (access-key-file.json)



SignWithSeedPhrase

Sign the transaction using the seed phrase



SignLater

Prepare unsigned transaction to sign it later